@@ -10,9 +10,6 @@ from .qemu import Qemu
 class QemuDut(Dut):
     """
     QEMU dut class
-
-    :ivar: app: :class:`pytest_embedded.app.App` or subclass instance
-    :ivar: qemu: :class:`pytest_embedded_qemu_idf.qemu.IdfQemu` instance
     """
 
     def __init__(
@@ -22,6 +19,12 @@ class QemuDut(Dut):
         pexpect_proc: Optional[pexpect.spawn] = None,
         **kwargs,
     ) -> None:
+        """
+        Args:
+            qemu: `Qemu` instance
+            app: `App` instance
+            pexpect_proc: `PexpectProcess` instance
+        """
         super().__init__(app, pexpect_proc, **kwargs)
         self.qemu = qemu
 
